######################################
######### Chapter 4 #################
######################################


## Writing and Running a Program in R 

### Writing Your Program

print("Welcome to Whataburger, can I take your order?")

drink <- c("I would like a Diet Coke to drink.")
eat <- c("I would like a number one combo, but on my burger I want it plain. Just cheese,
         meat, and bread.")

eat
drink


############################################
## Creating Your Variables and Dataset

# create variables
item <- c("cups", "plates", "burgers", "buns", "forks", "ketchup")
quantity <- c(46, 50, 100, 80, 60, 30)
month <- c(2, 3, 3, 3, 3, 4)
day <- c(14, 02, 04, 16, 24, 01)

# create dataset
orders <- data.frame(item, quantity, month, day)

# display dataset
orders


######################################################
## Manipulating Your Data Using the dplyr Package

# install packages used in chapter
# this line of code only needs to be run once 
# and then to be commented out
install.packages("tidyverse", dependencies = TRUE)

# load package 
library(tidyverse)

# load package 
library(dplyr)


### Sort Data: **arrange**

# reorder dataset according to quantity
arrange(orders, quantity)

# reorder dataset according to quantity
arrange(orders, desc(quantity))


### Choosing Observations or Rows: **filter**

# show order on March 4
filter(orders, month == 3, day == 4)


# create a new dataset based on order on March 4th
orders.March4 <- filter(orders, month == 3, day == 4)


### Choosing Variables or Columns: **select**

# show item and quantity only
select(orders, item, quantity)

# create a new dataset of item and quantity only
orders.itemquant <- select(orders, item, quantity)


### Creating New Variables: **mutate**


#### Creating New Variable Based on Computation

# create and add two new variables
mutate(orders, total_sum = sum(quantity), count=length(quantity))


# create a new dataset adding two new variables
orders.new <- mutate(orders, total_sum = sum(quantity), count=length(quantity))

# create a new grouped dataset
orders.month <- group_by(orders, month)

# create and add two new by-group variables
orders.month <- mutate(orders.month, total_month = sum(quantity), 
                       count_month = length(quantity))

# display new data
orders.month


#### Creating New Variable Based on Recoding

# create a new variable using recode function
orders.new <- mutate(orders, type = recode(item,
                                       "ketchup" = "food",
                                       "buns" = "food",
                                       "burgers" = "food",
                                       "cups" = "utensil",
                                       "plates" = "utensil",
                                       "forks" = "utensil"))

# display new data
orders.new

# create new variable using case_when function
orders.new <- mutate(orders, type2 = case_when(
  item=="cups" | item=="plates" | item=="forks" ~ "utensils",
  TRUE ~ "food"))

# display new data
orders.new


#### Creating New Variables by Replacing Certain Values of Existing Variables

# create new variables with corrected values
orders.new <- mutate(orders, 
                 quantity.new = replace(quantity, month==3 & day==4 & item=="burgers", 99),
                 day.new = replace(day, item=="ketchup" & quantity==30 & month==4, 10))

# display dataset
orders.new


## Rename a Variable

# change variable names
orders.new <- rename(orders, order.content = item)  

# show dataset to verify new variable name
orders.new



### Computing Summary Statistics and By-Group Summaries: **summarize** and **group_by**

# compute total, mean, maximum of quantity
summarize(orders, total_order = sum(quantity), avg_order = mean(quantity), 
          max_order=max(quantity))

# create a new grouped dataset
orders.month <- group_by(orders, month)

# compute by-group summary
summarize(orders.month, total_month = sum(quantity))


# create by-group summary dataset
quantity.month <- summarize(orders.month, total_month = sum(quantity))


##########################################################
## Chaining Different Data Manipulation Operations: **pipe (%>%)** 

# load package 
library(magrittr)

# compute by-group summary using pipe operator
orders %>%
  group_by(month) %>%
  summarize(total_month = sum(quantity))


# create by-group summary dataset using pipe operator
quantity.month <- orders %>%
                  group_by(month) %>%
                  summarize(total_month = sum(quantity))


# create a new dataset based on order on March 4th
orders.March4 <- orders %>%
  filter(month == 3, day == 4)

# create a new dataset of item and quantity only
orders.itemquant <- orders %>%
  select(item, quantity)

# create a new dataset adding two new variables
orders.new <- orders %>%
  mutate(total_sum = sum(quantity), count=length(quantity))

# create a new variable using recode function
orders.new <- orders %>%
  mutate(type = recode(item, "ketchup" = "food",
                             "buns" = "food",
                             "burgers" = "food",
                             "cups" = "utensil",
                             "plates" = "utensil",
                             "forks" = "utensil"))

# create new variable using case_when function
orders.new <- orders %>%
  mutate(type2 = case_when(
                 item=="cups" | item=="plates" | item=="forks" ~ "utensils",
                 TRUE ~ "food"))

# create new variables with corrected values
orders.new <- orders %>%
  mutate(quantity.new = replace(quantity, month==3 & day==4 & item=="burgers", 99),
         day.new = replace(day, item=="ketchup" & quantity==30 & month==4, 10))

# change variable names
orders <- orders %>%
    rename(order.content = item)  


# chaining

orders.new <- orders %>%
  mutate(total_sum = sum(quantity), count=length(quantity)) %>%
  mutate(type = recode(item, "ketchup" = "food",
                             "buns" = "food",
                             "burgers" = "food",
                             "cups" = "utensil",
                             "plates" = "utensil",
                             "forks" = "utensil")) %>%
  mutate(type2 = case_when(
                 item=="cups" | item=="plates" | item=="forks" ~ "utensils",
                 TRUE ~ "food")) %>%
  mutate(quantity.new = replace(quantity, month==3 & day==4 & item=="burgers", 99),
         day.new = replace(day, item=="ketchup" & quantity==30 & month==4, 10)) 


################################################
## Missing Value in R: **NA**

# create variables
item <- c("cups", "plates", "burgers", "buns", "forks", "ketchup")
quantity <- c(46, 50, NA, 80, 60, 30)
month <- c(2, 3, 3, 3, 3, 4)
day <- c(14, 02, 04, 16, 24, 01)

# create dataset
orders <- data.frame(item, quantity, month, day)

orders


# compute by-group summary using pipe operator
orders %>%
  group_by(month) %>%
  summarize(total_month = sum(quantity))


# compute by-group summary using pipe operator
orders %>%
  group_by(month) %>%
  summarize(total_month = sum(quantity, na.rm=TRUE))


# compute summary statistics
summary(orders)


# remove missing values in quantity
filter(orders, !is.na(quantity))


# remove all missing values
na.omit(orders)


